@@ -59,17 +59,17 @@ class LoadStreams:
     streams simultaneously, making it suitable for real-time video analysis tasks.
 
     Attributes:
-        sources (List[str]): The source input paths or URLs for the video streams.
+        sources (list[str]): The source input paths or URLs for the video streams.
         vid_stride (int): Video frame-rate stride.
         buffer (bool): Whether to buffer input streams.
         running (bool): Flag to indicate if the streaming thread is running.
         mode (str): Set to 'stream' indicating real-time capture.
-        imgs (List[List[np.ndarray]]): List of image frames for each stream.
-        fps (List[float]): List of FPS for each stream.
-        frames (List[int]): List of total frames for each stream.
-        threads (List[Thread]): List of threads for each stream.
-        shape (List[Tuple[int, int, int]]): List of shapes for each stream.
-        caps (List[cv2.VideoCapture]): List of cv2.VideoCapture objects for each stream.
+        imgs (list[list[np.ndarray]]): List of image frames for each stream.
+        fps (list[float]): List of FPS for each stream.
+        frames (list[int]): List of total frames for each stream.
+        threads (list[Thread]): List of threads for each stream.
+        shape (list[tuple[int, int, int]]): List of shapes for each stream.
+        caps (list[cv2.VideoCapture]): List of cv2.VideoCapture objects for each stream.
         bs (int): Batch size for processing.
         cv2_flag (int): OpenCV flag for image reading (grayscale or RGB).
 
@@ -245,7 +245,7 @@ class LoadScreenshots:
         sct (mss.mss): Screen capture object from `mss` library.
         bs (int): Batch size, set to 1.
         fps (int): Frames per second, set to 30.
-        monitor (Dict[str, int]): Monitor configuration details.
+        monitor (dict[str, int]): Monitor configuration details.
         cv2_flag (int): OpenCV flag for image reading (grayscale or RGB).
 
     Methods:
@@ -267,7 +267,7 @@ class LoadScreenshots:
             channels (int): Number of image channels (1 for grayscale, 3 for RGB).
         """
         check_requirements("mss")
-        import mss  # noqa
+        import mss
 
         source, *params = source.split()
         self.screen, left, top, width, height = 0, None, None, None, None  # default to full screen 0
@@ -314,9 +314,9 @@ class LoadImagesAndVideos:
     single image files, video files, and lists of image and video paths.
 
     Attributes:
-        files (List[str]): List of image and video file paths.
+        files (list[str]): List of image and video file paths.
         nf (int): Total number of files (images and videos).
-        video_flag (List[bool]): Flags indicating whether a file is a video (True) or an image (False).
+        video_flag (list[bool]): Flags indicating whether a file is a video (True) or an image (False).
         mode (str): Current mode, 'image' or 'video'.
         vid_stride (int): Stride for video frame-rate.
         bs (int): Batch size.
@@ -351,7 +351,7 @@ class LoadImagesAndVideos:
         Initialize dataloader for images and videos, supporting various input formats.
 
         Args:
-            path (str | Path | List): Path to images/videos, directory, or list of paths.
+            path (str | Path | list): Path to images/videos, directory, or list of paths.
             batch (int): Batch size for processing.
             vid_stride (int): Video frame-rate stride.
             channels (int): Number of image channels (1 for grayscale, 3 for RGB).
@@ -497,8 +497,8 @@ class LoadPilAndNumpy:
     validation and format conversion to ensure that the images are in the required format for downstream processing.
 
     Attributes:
-        paths (List[str]): List of image paths or autogenerated filenames.
-        im0 (List[np.ndarray]): List of images stored as Numpy arrays.
+        paths (list[str]): List of image paths or autogenerated filenames.
+        im0 (list[np.ndarray]): List of images stored as Numpy arrays.
         mode (str): Type of data being processed, set to 'image'.
         bs (int): Batch size, equivalent to the length of `im0`.
 
@@ -521,7 +521,7 @@ class LoadPilAndNumpy:
         Initialize a loader for PIL and Numpy images, converting inputs to a standardized format.
 
         Args:
-            im0 (PIL.Image.Image | np.ndarray | List): Single image or list of images in PIL or numpy format.
+            im0 (PIL.Image.Image | np.ndarray | list): Single image or list of images in PIL or numpy format.
             channels (int): Number of image channels (1 for grayscale, 3 for RGB).
         """
         if not isinstance(im0, list):
@@ -574,7 +574,7 @@ class LoadTensor:
         im0 (torch.Tensor): The input tensor containing the image(s) with shape (B, C, H, W).
         bs (int): Batch size, inferred from the shape of `im0`.
         mode (str): Current processing mode, set to 'image'.
-        paths (List[str]): List of image paths or auto-generated filenames.
+        paths (list[str]): List of image paths or auto-generated filenames.
 
     Methods:
         _single_check: Validates and formats an input tensor.
@@ -690,7 +690,7 @@ def get_best_youtube_url(url: str, method: str = "pytube") -> str | None:
 
     elif method == "pafy":
         check_requirements(("pafy", "youtube_dl==2020.12.2"))
-        import pafy  # noqa
+        import pafy
 
         return pafy.new(url).getbestvideo(preftype="mp4").url
 
