@@ -10,20 +10,20 @@ import torch
 import torch.nn as nn
 
 __all__ = (
+    "CBAM",
+    "ChannelAttention",
+    "Concat",
     "Conv",
     "Conv2",
-    "LightConv",
+    "ConvTranspose",
     "DWConv",
     "DWConvTranspose2d",
-    "ConvTranspose",
     "Focus",
     "GhostConv",
-    "ChannelAttention",
-    "SpatialAttention",
-    "CBAM",
-    "Concat",
-    "RepConv",
     "Index",
+    "LightConv",
+    "RepConv",
+    "SpatialAttention",
 )
 
 
@@ -675,7 +675,7 @@ class Concat(nn.Module):
         Concatenate input tensors along specified dimension.
 
         Args:
-            x (List[torch.Tensor]): List of input tensors.
+            x (list[torch.Tensor]): List of input tensors.
 
         Returns:
             (torch.Tensor): Concatenated tensor.
@@ -706,7 +706,7 @@ class Index(nn.Module):
         Select and return a particular index from input.
 
         Args:
-            x (List[torch.Tensor]): List of input tensors.
+            x (list[torch.Tensor]): List of input tensors.
 
         Returns:
             (torch.Tensor): Selected tensor.
