@@ -318,7 +318,7 @@ class ConfusionMatrix(DataExportMixin):
         task (str): The type of task, either 'detect' or 'classify'.
         matrix (np.ndarray): The confusion matrix, with dimensions depending on the task.
         nc (int): The number of category.
-        names (List[str]): The names of the classes, used as labels on the plot.
+        names (list[str]): The names of the classes, used as labels on the plot.
         matches (dict): Contains the indices of ground truths and predictions categorized into TP, FP and FN.
     """
 
@@ -327,7 +327,7 @@ class ConfusionMatrix(DataExportMixin):
         Initialize a ConfusionMatrix instance.
 
         Args:
-            names (Dict[int, str], optional): Names of classes, used as labels on the plot.
+            names (dict[int, str], optional): Names of classes, used as labels on the plot.
             task (str, optional): Type of task, either 'detect' or 'classify'.
             save_matches (bool, optional): Save the indices of GTs, TPs, FPs, FNs for visualization.
         """
@@ -346,7 +346,7 @@ class ConfusionMatrix(DataExportMixin):
 
         Args:
             mtype (str): Match type identifier ('TP', 'FP', 'FN' or 'GT').
-            batch (Dict[str, Any]): Batch data containing detection results with keys
+            batch (dict[str, Any]): Batch data containing detection results with keys
                 like 'bboxes', 'cls', 'conf', 'keypoints', 'masks'.
             idx (int): Index of the specific detection to append from the batch.
 
@@ -368,8 +368,8 @@ class ConfusionMatrix(DataExportMixin):
         Update confusion matrix for classification task.
 
         Args:
-            preds (List[N, min(nc,5)]): Predicted class labels.
-            targets (List[N, 1]): Ground truth class labels.
+            preds (list[N, min(nc,5)]): Predicted class labels.
+            targets (list[N, 1]): Ground truth class labels.
         """
         preds, targets = torch.cat(preds)[:, 0], torch.cat(targets)
         for p, t in zip(preds.cpu().numpy(), targets.cpu().numpy()):
@@ -386,10 +386,10 @@ class ConfusionMatrix(DataExportMixin):
         Update confusion matrix for object detection task.
 
         Args:
-            detections (Dict[str, torch.Tensor]): Dictionary containing detected bounding boxes and their associated information.
+            detections (dict[str, torch.Tensor]): Dictionary containing detected bounding boxes and their associated information.
                                        Should contain 'cls', 'conf', and 'bboxes' keys, where 'bboxes' can be
                                        Array[N, 4] for regular boxes or Array[N, 5] for OBB with angle.
-            batch (Dict[str, Any]): Batch dictionary containing ground truth data with 'bboxes' (Array[M, 4]| Array[M, 5]) and
+            batch (dict[str, Any]): Batch dictionary containing ground truth data with 'bboxes' (Array[M, 4]| Array[M, 5]) and
                 'cls' (Array[M]) keys, where M is the number of ground truth objects.
             conf (float, optional): Confidence threshold for detections.
             iou_thres (float, optional): IoU threshold for matching detections to ground truth.
@@ -397,11 +397,11 @@ class ConfusionMatrix(DataExportMixin):
         gt_cls, gt_bboxes = batch["cls"], batch["bboxes"]
         if self.matches is not None:  # only if visualization is enabled
             self.matches = {k: defaultdict(list) for k in {"TP", "FP", "FN", "GT"}}
-            for i in range(len(gt_cls)):
+            for i in range(gt_cls.shape[0]):
                 self._append_matches("GT", batch, i)  # store GT
         is_obb = gt_bboxes.shape[1] == 5  # check if boxes contains angle for OBB
         conf = 0.25 if conf in {None, 0.01 if is_obb else 0.001} else conf  # apply 0.25 if default val conf is passed
-        no_pred = len(detections["cls"]) == 0
+        no_pred = detections["cls"].shape[0] == 0
         if gt_cls.shape[0] == 0:  # Check if labels is empty
             if not no_pred:
                 detections = {k: detections[k][detections["conf"] > conf] for k in detections}
@@ -496,8 +496,8 @@ class ConfusionMatrix(DataExportMixin):
             for k in mbatch.keys():
                 labels[k] += mbatch[k]
 
-        labels = {k: torch.stack(v, 0) if len(v) else v for k, v in labels.items()}
-        if self.task != "obb" and len(labels["bboxes"]):
+        labels = {k: torch.stack(v, 0) if len(v) else torch.empty(0) for k, v in labels.items()}
+        if self.task != "obb" and labels["bboxes"].shape[0]:
             labels["bboxes"] = xyxy2xywh(labels["bboxes"])
         (save_dir / "visualizations").mkdir(parents=True, exist_ok=True)
         plot_images(
@@ -535,7 +535,7 @@ class ConfusionMatrix(DataExportMixin):
             array = array[keep_idx, :][:, keep_idx]  # slice matrix rows and cols
             n = (self.nc + k - 1) // k  # number of retained classes
         nc = nn = n if self.task == "classify" else n + 1  # adjust for background if needed
-        ticklabels = (names + ["background"]) if (0 < nn < 99) and (nn == nc) else "auto"
+        ticklabels = ([*names, "background"]) if (0 < nn < 99) and (nn == nc) else "auto"
         xy_ticks = np.arange(len(ticklabels))
         tick_fontsize = max(6, 15 - 0.1 * nc)  # Minimum size is 6
         label_fontsize = max(6, 12 - 0.1 * nc)
@@ -599,7 +599,7 @@ class ConfusionMatrix(DataExportMixin):
             decimals (int): Number of decimal places to round the output values to.
 
         Returns:
-            (List[Dict[str, float]]): A list of dictionaries, each representing one predicted class with corresponding values for all actual classes.
+            (list[dict[str, float]]): A list of dictionaries, each representing one predicted class with corresponding values for all actual classes.
 
         Examples:
             >>> results = model.val(data="coco8.yaml", plots=True)
@@ -608,7 +608,7 @@ class ConfusionMatrix(DataExportMixin):
         """
         import re
 
-        names = list(self.names.values()) if self.task == "classify" else list(self.names.values()) + ["background"]
+        names = list(self.names.values()) if self.task == "classify" else [*list(self.names.values()), "background"]
         clean_names, seen = [], set()
         for name in names:
             clean_name = re.sub(r"[^a-zA-Z0-9_]", "_", name)
@@ -651,7 +651,7 @@ def plot_pr_curve(
         py (np.ndarray): Y values for the PR curve.
         ap (np.ndarray): Average precision values.
         save_dir (Path, optional): Path to save the plot.
-        names (Dict[int, str], optional): Dictionary mapping class indices to class names.
+        names (dict[int, str], optional): Dictionary mapping class indices to class names.
         on_plot (callable, optional): Function to call after plot is saved.
     """
     import matplotlib.pyplot as plt  # scope for faster 'import ultralytics'
@@ -663,7 +663,7 @@ def plot_pr_curve(
         for i, y in enumerate(py.T):
             ax.plot(px, y, linewidth=1, label=f"{names[i]} {ap[i, 0]:.3f}")  # plot(recall, precision)
     else:
-        ax.plot(px, py, linewidth=1, color="grey")  # plot(recall, precision)
+        ax.plot(px, py, linewidth=1, color="gray")  # plot(recall, precision)
 
     ax.plot(px, py.mean(1), linewidth=3, color="blue", label=f"all classes {ap[:, 0].mean():.3f} mAP@0.5")
     ax.set_xlabel("Recall")
@@ -695,7 +695,7 @@ def plot_mc_curve(
         px (np.ndarray): X values for the metric-confidence curve.
         py (np.ndarray): Y values for the metric-confidence curve.
         save_dir (Path, optional): Path to save the plot.
-        names (Dict[int, str], optional): Dictionary mapping class indices to class names.
+        names (dict[int, str], optional): Dictionary mapping class indices to class names.
         xlabel (str, optional): X-axis label.
         ylabel (str, optional): Y-axis label.
         on_plot (callable, optional): Function to call after plot is saved.
@@ -708,7 +708,7 @@ def plot_mc_curve(
         for i, y in enumerate(py):
             ax.plot(px, y, linewidth=1, label=f"{names[i]}")  # plot(confidence, metric)
     else:
-        ax.plot(px, py.T, linewidth=1, color="grey")  # plot(confidence, metric)
+        ax.plot(px, py.T, linewidth=1, color="gray")  # plot(confidence, metric)
 
     y = smooth(py.mean(0), 0.1)
     ax.plot(px, y, linewidth=3, color="blue", label=f"all classes {y.max():.2f} at {px[y.argmax()]:.3f}")
@@ -780,7 +780,7 @@ def ap_per_class(
         plot (bool, optional): Whether to plot PR curves or not.
         on_plot (callable, optional): A callback to pass plots path and data when they are rendered.
         save_dir (Path, optional): Directory to save the PR curves.
-        names (Dict[int, str], optional): Dictionary of class names to plot PR curves.
+        names (dict[int, str], optional): Dictionary of class names to plot PR curves.
         eps (float, optional): A small value to avoid division by zero.
         prefix (str, optional): A prefix string for saving the plot files.
 
@@ -980,7 +980,7 @@ class Metric(SimpleClass):
 
     def fitness(self) -> float:
         """Return model fitness as a weighted combination of metrics."""
-        w = [0.0, 0.0, 0.1, 0.9]  # weights for [P, R, mAP@0.5, mAP@0.5:0.95]
+        w = [0.0, 0.0, 0.0, 1.0]  # weights for [P, R, mAP@0.5, mAP@0.5:0.95]
         return (np.nan_to_num(np.array(self.mean_results())) * w).sum()
 
     def update(self, results: tuple):
@@ -1034,11 +1034,11 @@ class DetMetrics(SimpleClass, DataExportMixin):
     Utility class for computing detection metrics such as precision, recall, and mean average precision (mAP).
 
     Attributes:
-        names (Dict[int, str]): A dictionary of class names.
+        names (dict[int, str]): A dictionary of class names.
         box (Metric): An instance of the Metric class for storing detection results.
-        speed (Dict[str, float]): A dictionary for storing execution times of different parts of the detection process.
+        speed (dict[str, float]): A dictionary for storing execution times of different parts of the detection process.
         task (str): The task type, set to 'detect'.
-        stats (Dict[str, List]): A dictionary containing lists for true positives, confidence scores, predicted classes, target classes, and target images.
+        stats (dict[str, list]): A dictionary containing lists for true positives, confidence scores, predicted classes, target classes, and target images.
         nt_per_class: Number of targets per class.
         nt_per_image: Number of targets per image.
 
@@ -1063,7 +1063,7 @@ class DetMetrics(SimpleClass, DataExportMixin):
         Initialize a DetMetrics instance with a save directory, plot flag, and class names.
 
         Args:
-            names (Dict[int, str], optional): Dictionary of class names.
+            names (dict[int, str], optional): Dictionary of class names.
         """
         self.names = names
         self.box = Metric()
@@ -1078,7 +1078,7 @@ class DetMetrics(SimpleClass, DataExportMixin):
         Update statistics by appending new values to existing stat collections.
 
         Args:
-            stat (Dict[str, any]): Dictionary containing new statistical values to append.
+            stat (dict[str, any]): Dictionary containing new statistical values to append.
                          Keys should match existing keys in self.stats.
         """
         for k in self.stats.keys():
@@ -1094,7 +1094,7 @@ class DetMetrics(SimpleClass, DataExportMixin):
             on_plot (callable, optional): Function to call after plots are generated. Defaults to None.
 
         Returns:
-            (Dict[str, np.ndarray]): Dictionary containing concatenated statistics arrays.
+            (dict[str, np.ndarray]): Dictionary containing concatenated statistics arrays.
         """
         stats = {k: np.concatenate(v, 0) for k, v in self.stats.items()}  # to numpy
         if not stats:
@@ -1152,8 +1152,8 @@ class DetMetrics(SimpleClass, DataExportMixin):
     @property
     def results_dict(self) -> dict[str, float]:
         """Return dictionary of computed performance metrics and statistics."""
-        keys = self.keys + ["fitness"]
-        values = ((float(x) if hasattr(x, "item") else x) for x in (self.mean_results() + [self.fitness]))
+        keys = [*self.keys, "fitness"]
+        values = ((float(x) if hasattr(x, "item") else x) for x in ([*self.mean_results(), self.fitness]))
         return dict(zip(keys, values))
 
     @property
@@ -1176,7 +1176,7 @@ class DetMetrics(SimpleClass, DataExportMixin):
            decimals (int): Number of decimal places to round the metrics values to.
 
         Returns:
-           (List[Dict[str, Any]]): A list of dictionaries, each representing one class with corresponding metric values.
+           (list[dict[str, Any]]): A list of dictionaries, each representing one class with corresponding metric values.
 
         Examples:
            >>> results = model.val(data="coco8.yaml")
@@ -1206,12 +1206,12 @@ class SegmentMetrics(DetMetrics):
     Calculate and aggregate detection and segmentation metrics over a given set of classes.
 
     Attributes:
-        names (Dict[int, str]): Dictionary of class names.
+        names (dict[int, str]): Dictionary of class names.
         box (Metric): An instance of the Metric class for storing detection results.
         seg (Metric): An instance of the Metric class to calculate mask segmentation metrics.
-        speed (Dict[str, float]): A dictionary for storing execution times of different parts of the detection process.
+        speed (dict[str, float]): A dictionary for storing execution times of different parts of the detection process.
         task (str): The task type, set to 'segment'.
-        stats (Dict[str, List]): A dictionary containing lists for true positives, confidence scores, predicted classes, target classes, and target images.
+        stats (dict[str, list]): A dictionary containing lists for true positives, confidence scores, predicted classes, target classes, and target images.
         nt_per_class: Number of targets per class.
         nt_per_image: Number of targets per image.
 
@@ -1232,7 +1232,7 @@ class SegmentMetrics(DetMetrics):
         Initialize a SegmentMetrics instance with a save directory, plot flag, and class names.
 
         Args:
-            names (Dict[int, str], optional): Dictionary of class names.
+            names (dict[int, str], optional): Dictionary of class names.
         """
         DetMetrics.__init__(self, names)
         self.seg = Metric()
@@ -1249,7 +1249,7 @@ class SegmentMetrics(DetMetrics):
             on_plot (callable, optional): Function to call after plots are generated. Defaults to None.
 
         Returns:
-            (Dict[str, np.ndarray]): Dictionary containing concatenated statistics arrays.
+            (dict[str, np.ndarray]): Dictionary containing concatenated statistics arrays.
         """
         stats = DetMetrics.process(self, save_dir, plot, on_plot=on_plot)  # process box stats
         results_mask = ap_per_class(
@@ -1270,7 +1270,8 @@ class SegmentMetrics(DetMetrics):
     @property
     def keys(self) -> list[str]:
         """Return a list of keys for accessing metrics."""
-        return DetMetrics.keys.fget(self) + [
+        return [
+            *DetMetrics.keys.fget(self),
             "metrics/precision(M)",
             "metrics/recall(M)",
             "metrics/mAP50(M)",
@@ -1298,7 +1299,8 @@ class SegmentMetrics(DetMetrics):
     @property
     def curves(self) -> list[str]:
         """Return a list of curves for accessing specific metrics curves."""
-        return DetMetrics.curves.fget(self) + [
+        return [
+            *DetMetrics.curves.fget(self),
             "Precision-Recall(M)",
             "F1-Confidence(M)",
             "Precision-Confidence(M)",
@@ -1320,7 +1322,7 @@ class SegmentMetrics(DetMetrics):
             decimals (int): Number of decimal places to round the metrics values to.
 
         Returns:
-            (List[Dict[str, Any]]): A list of dictionaries, each representing one class with corresponding metric values.
+            (list[dict[str, Any]]): A list of dictionaries, each representing one class with corresponding metric values.
 
         Examples:
             >>> results = model.val(data="coco8-seg.yaml")
@@ -1343,12 +1345,12 @@ class PoseMetrics(DetMetrics):
     Calculate and aggregate detection and pose metrics over a given set of classes.
 
     Attributes:
-        names (Dict[int, str]): Dictionary of class names.
+        names (dict[int, str]): Dictionary of class names.
         pose (Metric): An instance of the Metric class to calculate pose metrics.
         box (Metric): An instance of the Metric class for storing detection results.
-        speed (Dict[str, float]): A dictionary for storing execution times of different parts of the detection process.
+        speed (dict[str, float]): A dictionary for storing execution times of different parts of the detection process.
         task (str): The task type, set to 'pose'.
-        stats (Dict[str, List]): A dictionary containing lists for true positives, confidence scores, predicted classes, target classes, and target images.
+        stats (dict[str, list]): A dictionary containing lists for true positives, confidence scores, predicted classes, target classes, and target images.
         nt_per_class: Number of targets per class.
         nt_per_image: Number of targets per image.
 
@@ -1369,7 +1371,7 @@ class PoseMetrics(DetMetrics):
         Initialize the PoseMetrics class with directory path, class names, and plotting options.
 
         Args:
-            names (Dict[int, str], optional): Dictionary of class names.
+            names (dict[int, str], optional): Dictionary of class names.
         """
         super().__init__(names)
         self.pose = Metric()
@@ -1386,7 +1388,7 @@ class PoseMetrics(DetMetrics):
             on_plot (callable, optional): Function to call after plots are generated.
 
         Returns:
-            (Dict[str, np.ndarray]): Dictionary containing concatenated statistics arrays.
+            (dict[str, np.ndarray]): Dictionary containing concatenated statistics arrays.
         """
         stats = DetMetrics.process(self, save_dir, plot, on_plot=on_plot)  # process box stats
         results_pose = ap_per_class(
@@ -1407,7 +1409,8 @@ class PoseMetrics(DetMetrics):
     @property
     def keys(self) -> list[str]:
         """Return a list of evaluation metric keys."""
-        return DetMetrics.keys.fget(self) + [
+        return [
+            *DetMetrics.keys.fget(self),
             "metrics/precision(P)",
             "metrics/recall(P)",
             "metrics/mAP50(P)",
@@ -1435,7 +1438,8 @@ class PoseMetrics(DetMetrics):
     @property
     def curves(self) -> list[str]:
         """Return a list of curves for accessing specific metrics curves."""
-        return DetMetrics.curves.fget(self) + [
+        return [
+            *DetMetrics.curves.fget(self),
             "Precision-Recall(B)",
             "F1-Confidence(B)",
             "Precision-Confidence(B)",
@@ -1461,7 +1465,7 @@ class PoseMetrics(DetMetrics):
             decimals (int): Number of decimal places to round the metrics values to.
 
         Returns:
-            (List[Dict[str, Any]]): A list of dictionaries, each representing one class with corresponding metric values.
+            (list[dict[str, Any]]): A list of dictionaries, each representing one class with corresponding metric values.
 
         Examples:
             >>> results = model.val(data="coco8-pose.yaml")
@@ -1527,7 +1531,7 @@ class ClassifyMetrics(SimpleClass, DataExportMixin):
     @property
     def results_dict(self) -> dict[str, float]:
         """Return a dictionary with model's performance metrics and fitness score."""
-        return dict(zip(self.keys + ["fitness"], [self.top1, self.top5, self.fitness]))
+        return dict(zip([*self.keys, "fitness"], [self.top1, self.top5, self.fitness]))
 
     @property
     def keys(self) -> list[str]:
@@ -1553,7 +1557,7 @@ class ClassifyMetrics(SimpleClass, DataExportMixin):
             decimals (int): Number of decimal places to round the metrics values to.
 
         Returns:
-            (List[Dict[str, float]]): A list with one dictionary containing Top-1 and Top-5 classification accuracy.
+            (list[dict[str, float]]): A list with one dictionary containing Top-1 and Top-5 classification accuracy.
 
         Examples:
             >>> results = model.val(data="imagenet10")
@@ -1568,11 +1572,11 @@ class OBBMetrics(DetMetrics):
     Metrics for evaluating oriented bounding box (OBB) detection.
 
     Attributes:
-        names (Dict[int, str]): Dictionary of class names.
+        names (dict[int, str]): Dictionary of class names.
         box (Metric): An instance of the Metric class for storing detection results.
-        speed (Dict[str, float]): A dictionary for storing execution times of different parts of the detection process.
+        speed (dict[str, float]): A dictionary for storing execution times of different parts of the detection process.
         task (str): The task type, set to 'obb'.
-        stats (Dict[str, List]): A dictionary containing lists for true positives, confidence scores, predicted classes, target classes, and target images.
+        stats (dict[str, list]): A dictionary containing lists for true positives, confidence scores, predicted classes, target classes, and target images.
         nt_per_class: Number of targets per class.
         nt_per_image: Number of targets per image.
 
@@ -1585,7 +1589,7 @@ class OBBMetrics(DetMetrics):
         Initialize an OBBMetrics instance with directory, plotting, and class names.
 
         Args:
-            names (Dict[int, str], optional): Dictionary of class names.
+            names (dict[int, str], optional): Dictionary of class names.
         """
         DetMetrics.__init__(self, names)
         # TODO: probably remove task as well
