@@ -56,7 +56,7 @@ class Profile(contextlib.ContextDecorator):
         self.start = self.time()
         return self
 
-    def __exit__(self, type, value, traceback):  # noqa
+    def __exit__(self, type, value, traceback):
         """Stop timing."""
         self.dt = self.time() - self.start  # delta-time
         self.t += self.dt  # accumulate dt
@@ -236,10 +236,10 @@ def scale_image(masks, im0_shape, ratio_pad=None):
         pad = ratio_pad[1]
 
     pad_w, pad_h = pad
-    top = int(round(pad_h - 0.1))
-    left = int(round(pad_w - 0.1))
-    bottom = im1_h - int(round(pad_h + 0.1))
-    right = im1_w - int(round(pad_w + 0.1))
+    top = round(pad_h - 0.1)
+    left = round(pad_w - 0.1)
+    bottom = im1_h - round(pad_h + 0.1)
+    right = im1_w - round(pad_w + 0.1)
 
     if len(masks.shape) < 2:
         raise ValueError(f'"len of masks shape" should be 2 or 3, but got {len(masks.shape)}')
@@ -599,9 +599,9 @@ def scale_masks(masks, shape, padding: bool = True):
     if padding:
         pad_w /= 2
         pad_h /= 2
-    top, left = (int(round(pad_h - 0.1)), int(round(pad_w - 0.1))) if padding else (0, 0)
-    bottom = mh - int(round(pad_h + 0.1))
-    right = mw - int(round(pad_w + 0.1))
+    top, left = (round(pad_h - 0.1), round(pad_w - 0.1)) if padding else (0, 0)
+    bottom = mh - round(pad_h + 0.1)
+    right = mw - round(pad_w + 0.1)
     return F.interpolate(masks[..., top:bottom, left:right], shape, mode="bilinear")  # NCHW masks
 
 
